<?php

namespace App\Admin\Controllers;

//use App\Admin\Repositories\LawyerCost;
use App\Admin\Repositories\Lawyer;
use App\Models\LawyerCost as ModelLawyerCost;
use Dcat\Admin\Form;
use Dcat\Admin\Grid;
use Dcat\Admin\Show;
use Dcat\Admin\Http\Controllers\AdminController;

class LawyerCostController extends AdminController
{
    /**
     * Make a grid builder.
     *
     * @return Grid
     */
    protected function grid()
    {
        return Grid::make(new Lawyer(), function (Grid $grid) {
            $grid->column('id')->sortable();
            $grid->column('number', '律师编号');
            $grid->column('name', '律师姓名');
            $grid->column('basic_salary', '基本工资');
            $grid->column('special_additional', '专项附加');
            $grid->column('social', '社保');
            $grid->column('accumulation_fund', '公积金');
            $grid->column('annual_inspection_fee', '律所年检费');
            $grid->column('annuity', '律所年金');
            $grid->column('posting_tickets_fee', '贴票成本');
            $grid->column('assistant_fee', '助理律师成本');
            $grid->column('office_rental_fee', '办公租赁成本');
            $grid->column('noticket_cost', '无票成本');
            $grid->column('personal_income_tax', '个人所得税');

            $grid->disableViewButton();
            $grid->disableEditButton();

            $grid->filter(function (Grid\Filter $filter) {
                // 更改为 panel 布局
                $filter->panel();
                $filter->like('number', '律师编号')->width(3);
                $filter->like('name', '律师姓名')->width(3);
                $filter->like('year', '年份')->width(3)->default(date("Y"));
                //$filter->date('sign_at')->format('YYYY-MM-DD');
            });

            $grid->actions(function (Grid\Displayers\Actions $actions) {
                //$actions->append(new UserBuyCode($actions->row->id));
                //成本汇总
                $actions->append('<a href="/lycost-collect?no=' . $this->number . '" alt="成本汇总" target="_blank">成本汇总</a>');
                // 成本明细
                $actions->append('<a href="/lycost-list?no=' . $this->number . '" alt="成本明细" target="_blank">成本明细</a>');

                // 或者使用 RowAction 来添加按钮
                //$actions->append(RowAction::make('自定义按钮')->route('custom.route'));
            });
        });
    }
    protected function grid2()
    {
        return Grid::make(new ModelLawyerCost(), function (Grid $grid) {
            $grid->column('id')->sortable();
            $grid->column('year');
            $grid->column('month');
            $grid->column('number');
            $grid->column('lname');
            $grid->column('basic_salary');
            $grid->column('social_person_fee');
            $grid->column('social_company_fee');
            $grid->column('accumulation_fund_person_fee');
            $grid->column('accumulation_fund_company_fee');
            $grid->column('annual_inspection_fee');
            $grid->column('annuity');
            $grid->column('office_rental_fee');
            $grid->column('noticket_cost');
            $grid->column('posting_tickets_fee');
            $grid->column('assistant_fee');
            $grid->column('special_additional');
            $grid->column('advance_fee');
            $grid->column('personal_income_tax');
            $grid->column('created_at');
            $grid->column('updated_at')->sortable();

            $grid->filter(function (Grid\Filter $filter) {
                $filter->equal('id');
            });
        });
    }

    /**
     * Make a show builder.
     *
     * @param mixed $id
     *
     * @return Show
     */
    protected function detail($id)
    {
        return Show::make($id, new ModelLawyerCost(), function (Show $show) {
            $show->field('id');
            $show->field('year');
            $show->field('month');
            $show->field('number');
            $show->field('lname');
            $show->field('basic_salary');
            $show->field('social_person_fee');
            $show->field('social_company_fee');
            $show->field('accumulation_fund_person_fee');
            $show->field('accumulation_fund_company_fee');
            $show->field('annual_inspection_fee');
            $show->field('annuity');
            $show->field('office_rental_fee');
            $show->field('noticket_cost');
            $show->field('posting_tickets_fee');
            $show->field('assistant_fee');
            $show->field('special_additional');
            $show->field('advance_fee');
            $show->field('personal_income_tax');
            $show->field('created_at');
            $show->field('updated_at');
        });
    }

    /**
     * Make a form builder.
     *
     * @return Form
     */
    protected function form()
    {
        return Form::make(new ModelLawyerCost(), function (Form $form) {
            $form->display('id');
            $form->text('year');
            $form->select('month')->options(ModelLawyerCost::MONTH);
            $form->text('number');
            $form->text('lname');
            $form->text('basic_salary');
            $form->text('social_person_fee');
            $form->text('social_company_fee');
            //$form->display('social', '社保')->default(100);
            $form->text('accumulation_fund_person_fee');
            $form->text('accumulation_fund_company_fee');
            $form->text('annual_inspection_fee');
            $form->text('annuity');
            $form->text('office_rental_fee');
            //$form->text('noticket_cost');
            //$form->text('posting_tickets_fee');
            $form->text('assistant_fee');
            $form->text('special_additional');
            $form->text('advance_fee');
            $form->text('personal_income_tax');

            $form->disableCreatingCheck();
            $form->disableEditingCheck();
            $form->disableViewCheck();
            $form->disableDeleteButton();
            $form->disableViewButton();

            $form->display('created_at');
            $form->display('updated_at');
        });
    }
}
